| fglm | R Documentation |
fglm() inherits the usage of glm, and performs forward regression selection for generalized linear models.
fglm(
formula,
family = gaussian,
data,
weights,
subset,
na.action,
start = NULL,
etastart,
mustart,
offset,
control = list(...),
model = TRUE,
method = "glm.fit",
x = FALSE,
y = TRUE,
singular.ok = TRUE,
contrasts = NULL,
...,
selectFun = logLik,
stopFun = "EBIC",
keep = NULL,
maxK = NULL,
verbose = FALSE
)
fglm.fit(
x,
y,
weights = rep.int(1, NROW(y)),
start = NULL,
etastart = NULL,
mustart = NULL,
offset = rep.int(0, NROW(y)),
family = gaussian(),
control = list(),
intercept = TRUE,
singular.ok = TRUE,
selectFun = "logLik",
stopFun = "EBIC",
keep = NULL,
maxK = NULL,
verbose = FALSE
)
formula |
Parameter passed to glm. |
family |
Parameter passed to glm. |
data |
Parameter passed to glm. |
weights |
Parameter passed to glm. |
subset |
Parameter passed to glm. |
na.action |
Parameter passed to glm. |
start |
Parameter passed to glm. |
etastart |
Parameter passed to glm. |
mustart |
Parameter passed to glm. |
offset |
Parameter passed to glm. |
control |
Parameter passed to glm. |
model |
Parameter passed to glm. |
method |
Parameter passed to glm. |
x |
Parameter passed to glm. |
y |
Parameter passed to glm. |
singular.ok |
Parameter passed to glm. |
contrasts |
Parameter passed to glm. |
... |
Parameters passed to glm. |
selectFun |
Parameter passed to frs. |
stopFun |
Parameter passed to frs. |
keep |
Parameter passed to frs. |
maxK |
Parameter passed to frs. |
verbose |
Parameter passed to frs. |
intercept |
Parameter passed to glm.fit. |
A glm model object fitted on the selected features.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.