| flm | R Documentation |
flm() inherits the usage of the function lm, and performs forward regression selection for linear models.
flm(
formula,
data,
subset,
weights,
na.action,
method = "qr",
model = TRUE,
x = FALSE,
y = FALSE,
qr = TRUE,
singular.ok = TRUE,
contrasts = NULL,
offset,
...,
selectFun = logLik,
stopFun = "EBIC",
keep = NULL,
maxK = NULL,
verbose = FALSE
)
flm.fit(
x,
y,
offset = NULL,
method = "qr",
tol = 1e-07,
singular.ok = TRUE,
...,
selectFun = "logLik",
stopFun = "EBIC",
keep = NULL,
maxK = NULL,
verbose = FALSE
)
formula |
Parameter passed to lm. |
data |
Parameter passed to lm. |
subset |
Parameter passed to lm. |
weights |
Parameter passed to lm. |
na.action |
Parameter passed to lm. |
method |
Parameter passed to lm. |
model |
Parameter passed to lm. |
x |
Parameter passed to lm. |
y |
Parameter passed to lm. |
qr |
Parameter passed to lm. |
singular.ok |
Parameter passed to lm. |
contrasts |
Parameter passed to lm. |
offset |
Parameter passed to lm or lm.fit. |
... |
Parameters passed to lm or lm.fit. |
selectFun |
Parameter passed to frs. |
stopFun |
Parameter passed to frs. |
keep |
Parameter passed to frs. |
maxK |
Parameter passed to frs. |
verbose |
Parameter passed to frs. |
tol |
Parameter passed to lm.fit. |
A lm model object fitted on the selected features.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.