frs: Forward Regression Selection Framework

View source: R/frs.R

frsR Documentation

Forward Regression Selection Framework

Description

frs() is a generic workhorse function of forward regression selection for parametric regression.

Usage

frs(
  xmat,
  yvec,
  fitFun,
  ...,
  use.formula = TRUE,
  use.intercept = TRUE,
  selectFun = logLik,
  stopFun = "EBIC",
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

Arguments

xmat

See pboost.

yvec

See pboost.

fitFun

See pboost.

...

See pboost.

use.formula

See pboost.

use.intercept

See pboost.

selectFun

A function to evaluate the importance of an unselected feature when it is added to current model. The default is logLik, meaning that the feature with the largest post-added log-likelihood is identified as the next one to be added to the model. Note that selectFun is only used for selecting features, and it does not affect the stopping rule of forward regression selection, which is determined by stopFun.

stopFun

See pboost.

keep

See pboost.

maxK

See pboost.

verbose

See pboost.

Value

Model object fitted on the selected features.

See Also

fbetareg, fcoxph, fglm, flm, frq, fsar.


pboost documentation built on May 24, 2026, 9:08 a.m.