pboost: Profile Boosting Framework

View source: R/pboost.R

pboostR Documentation

Profile Boosting Framework

Description

pboost() is the generic workhorse function of profile boosting framework for parametric regression.

Usage

pboost(
  xmat,
  yvec,
  fitFun,
  scoreFun,
  stopFun = "EBIC",
  ...,
  use.formula = TRUE,
  use.intercept = TRUE,
  keep = NULL,
  maxK = NULL,
  verbose = FALSE
)

Arguments

xmat

Numeric feature matrix.

yvec

Response vector.

fitFun

Function to fit the empirical risk function in the form fitFun(formula, data, ...).

scoreFun

Function to compute the derivative, denoted by \frac{\partial \ell(y, \eta)}{\partial \eta}, of empirical risk function in the form scoreFun(object), where object is returned by fitFun. scoreFun() should return a vector with the same length of y in data.

stopFun

Stopping rule for profile boosting, which has the form stopFun(object) to evaluate the performance of model object returned by fitFun, such as EBIC or BIC.

...

Additional arguments to be passed to fitFun.

use.formula

Whether to use formula interface for model fitting. Default to TRUE. When use.formula=TRUE, the the model fitting function has the form fitFun(formula, data, ...); otherwise, fitFun(x, y, ...).

use.intercept

Include intercept in the model fitting? Valid only when use.formula=TRUE.

keep

Vector of indices or feature names initial features to include.

maxK

Maximal number of identified features. If maxK is specified, it will suppress stopFun, saying that the profile boosting continues until the procedure identifies maxK features. The pre-specified features in keep are counted toward maxK.

verbose

Print the procedure path?

Value

Model object fitted on the selected features.

See Also

pbetareg, pcoxph, pglm, plm, prq, psar.


pboost documentation built on May 24, 2026, 9:08 a.m.