pboost-package: pboost: Profile Boosting Framework for Parametric Models

pboost-packageR Documentation

pboost: Profile Boosting Framework for Parametric Models

Description

A profile boosting framework for feature selection in parametric models. It offers a unified interface pboost() and several wrapped models, including linear model, generalized linear models, quantile regression, Cox proportional hazards model, beta regression, spatial auto-regressive models.

Author(s)

Maintainer: Zengchao Xu zengc.xu@aliyun.com [copyright holder]

Authors:

See Also

Useful links:


pboost documentation built on May 24, 2026, 9:08 a.m.