EBIC: Extended Bayesian Information Criterion

View source: R/EBIC.R

EBICR Documentation

Extended Bayesian Information Criterion

Description

The Extended BIC possesses the selection consistency in high-dimensional model.

It can be called by the fitted model that has standard logLik method to access the attributes nobs and df, such as lm, glm.

Usage

EBIC(object, p, p.keep, ...)

## S3 method for class 'betareg'
EBIC(object, p, p.keep, ...)

## S3 method for class 'coxph'
EBIC(object, p, p.keep, ...)

## S3 method for class 'glm'
EBIC(object, p, p.keep, ...)

## S3 method for class 'lm'
EBIC(object, p, p.keep, ...)

## S3 method for class 'rq'
EBIC(object, p, p.keep, ...)

Arguments

object

Fitted model object.

p

Total number of candidate features, which is available in pboost.

p.keep

Number of features that are pre-specified to be kept in model.

...

Additional parameters, which is available in pboost.

Details

The extended BIC (EBIC) is defined as

EBIC(obj) = BIC(obj) + 2 * r * log(choose(p - |p.keep|, df - |p.keep|)).

Value

A function to obtain the EBIC value of a fitted object.

References

  • Jiahua Chen and Zehua Chen (2008). Extended Bayesian information criteria for model selection with large model spaces. Biometrika, 95(3):759–771. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/biomet/asn034")}

  • Jiahua Chen and Zehua Chen (2012). Extended BIC for small-n-large-p sparse GLM. Statistical Sinica, 22(2):555–574. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5705/ss.2010.216")}

See Also

plm, pglm, pcoxph, prq, pbetareg.


pboost documentation built on Jan. 9, 2026, 1:07 a.m.