| EBIC | R Documentation |
The Extended BIC possesses the selection consistency in high-dimensional model.
It can be called by the fitted model that has standard logLik method
to access the attributes nobs and df, such as lm, glm.
EBIC(object, p, p.keep, ...)
## S3 method for class 'betareg'
EBIC(object, p, p.keep, ...)
## S3 method for class 'coxph'
EBIC(object, p, p.keep, ...)
## S3 method for class 'glm'
EBIC(object, p, p.keep, ...)
## S3 method for class 'lm'
EBIC(object, p, p.keep, ...)
## S3 method for class 'rq'
EBIC(object, p, p.keep, ...)
object |
Fitted model object. |
p |
Total number of candidate features, which is available in pboost. |
p.keep |
Number of features that are pre-specified to be kept in model. |
... |
Additional parameters, which is available in pboost. |
The extended BIC (EBIC) is defined as
EBIC(obj) = BIC(obj) + 2 * r * log(choose(p - |p.keep|, df - |p.keep|)).
A function to obtain the EBIC value of a fitted object.
Jiahua Chen and Zehua Chen (2008). Extended Bayesian information criteria for model selection with large model spaces. Biometrika, 95(3):759–771. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/biomet/asn034")}
Jiahua Chen and Zehua Chen (2012). Extended BIC for small-n-large-p sparse GLM. Statistical Sinica, 22(2):555–574. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5705/ss.2010.216")}
plm, pglm, pcoxph, prq, pbetareg.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.