| frs | R Documentation |
frs() is a generic workhorse function of forward regression selection for parametric regression.
frs(
xmat,
yvec,
fitFun,
...,
use.formula = TRUE,
use.intercept = TRUE,
selectFun = logLik,
stopFun = "EBIC",
keep = NULL,
maxK = NULL,
verbose = FALSE
)
xmat |
See pboost. |
yvec |
See pboost. |
fitFun |
See pboost. |
... |
See pboost. |
use.formula |
See pboost. |
use.intercept |
See pboost. |
selectFun |
A function to evaluate the importance of an unselected feature when it is added to current model.
The default is |
stopFun |
See pboost. |
keep |
See pboost. |
maxK |
See pboost. |
verbose |
See pboost. |
Model object fitted on the selected features.
fbetareg, fcoxph, fglm, flm, frq, fsar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.