| pboost | R Documentation |
pboost() is the generic workhorse function of profile boosting
framework for parametric regression.
pboost(
xmat,
yvec,
fitFun,
scoreFun,
stopFun = "EBIC",
...,
use.formula = TRUE,
use.intercept = TRUE,
keep = NULL,
maxK = NULL,
verbose = FALSE
)
xmat |
Numeric feature matrix. |
yvec |
Response vector. |
fitFun |
Function to fit the empirical risk function in
the form |
scoreFun |
Function to compute the derivative, denoted by |
stopFun |
Stopping rule for profile boosting, which has the form
|
... |
Additional arguments to be passed to |
use.formula |
Whether to use formula interface for model fitting. Default to |
use.intercept |
Include intercept in the model fitting? Valid only when |
keep |
Vector of indices or feature names initial features to include. |
maxK |
Maximal number of identified features.
If |
verbose |
Print the procedure path? |
Model object fitted on the selected features.
pbetareg, pcoxph, pglm, plm, prq, psar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.