| pboost | R Documentation |
pboost is the generic workhorse function of profile boosting
framework for parametric regression.
pboost(
formula,
data,
fitFun,
scoreFun,
stopFun,
...,
keep = NULL,
maxK = NULL,
verbose = FALSE
)
formula |
An object of class formula of the form The following restrictions and recommendations apply:
|
data |
An data frame containing the variables in the model. |
fitFun |
Function to fit the empirical risk function in
the form |
scoreFun |
Function to compute the derivative of empirical
risk function in the form |
stopFun |
Stopping rule for profile boosting, which has the form
|
... |
Additional arguments to be passed to |
keep |
Initial set of features that are included in model fitting.
If |
maxK |
Maximal number of identified features.
If |
verbose |
Print the procedure path? |
Model object fitted on the selected features.
set.seed(2025)
n <- 200
p <- 300
x <- matrix(rnorm(n*p), n)
eta <- drop(x[, 1:3] %*% runif(3, 1.0, 1.5))
y <- rbinom(n, 1, 1/(1+exp(-eta)))
DF <- data.frame(y, x)
scoreLogistic <- function(object) {
eta.hat <- object[["linear.predictors"]]
return(object[["y"]] - 1/(1+exp(-eta.hat)))
}
( result <- pboost(y~., DF, glm, scoreLogistic, EBIC, family="binomial") )
attr(terms(formula(result), data=DF), "term.labels")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.