| pboost-package | R Documentation |
A profile boosting framework for feature selection in parametric models. It offers a unified interface pboost() and several wrapped models, including linear model, generalized linear models, quantile regression, Cox proportional hazards model, beta regression, spatial auto-regressive models.
Maintainer: Zengchao Xu zengc.xu@aliyun.com [copyright holder]
Authors:
Zengchao Xu zengc.xu@aliyun.com [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.