pboost-package: pboost: Profile Boosting Framework for Parametric Models

pboost-packageR Documentation

pboost: Profile Boosting Framework for Parametric Models

Description

A profile boosting framework for feature selection in parametric models. It offers a unified interface pboost() and several wrapped models, including linear model, generalized linear models, quantile regression, Cox proportional hazards model, beta regression. An S3 interface EBIC() is provided as the stopping rule for the profile boosting by default.

Author(s)

Maintainer: Zengchao Xu zengc.xu@aliyun.com

See Also

Useful links:


pboost documentation built on Jan. 9, 2026, 1:07 a.m.