| plm | R Documentation |
plm inherits the usage of the built-in function lm.
plm(
formula,
data,
subset,
weights,
na.action,
method = "qr",
model = TRUE,
x = FALSE,
y = FALSE,
qr = TRUE,
singular.ok = TRUE,
contrasts = NULL,
offset,
...,
stopFun = EBIC,
keep = NULL,
maxK = NULL,
verbose = FALSE
)
formula |
See pboost. |
data |
See pboost. |
subset |
Parameters passed to lm. |
weights |
Parameters passed to lm. |
na.action |
Parameters passed to lm. |
method |
Parameters passed to lm. |
model |
Parameters passed to lm. |
x |
Parameters passed to lm. |
y |
Parameters passed to lm. |
qr |
Parameters passed to lm. |
singular.ok |
Parameters passed to lm. |
contrasts |
Parameters passed to lm. |
offset |
Parameters passed to lm. |
... |
Parameters passed to lm. |
stopFun |
Parameters passed to pboost. |
keep |
Parameters passed to pboost. |
maxK |
Parameters passed to pboost. |
verbose |
Parameters passed to pboost. |
plm is an equivalent implementation to the sequential lasso method
proposed by Luo and Chen(2014, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01621459.2013.877275")}).
An lm model object fitted on the selected features.
Zengchao Xu, Shan Luo and Zehua Chen (2022). Partial profile score feature selection in high-dimensional generalized linear interaction models. Statistics and Its Interface. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.4310/21-SII706")}
Shan Luo and Zehua Chen (2014). A Sequential Lasso Method for Feature Selection with Ultra-High Dimensional Feature Space. Journal of the American Statistical Association, 109(507):223–232. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01621459.2013.877275")}
set.seed(2025)
n <- 300
p <- 200
x <- matrix(rnorm(n*p), n)
eta <- drop( x[, 1:3] %*% runif(3, 1.0, 1.5) )
y <- eta + rnorm(n, sd=sd(eta))
DF <- data.frame(y, x)
plm(y ~ ., DF, verbose=TRUE)
plm(y ~ ., DF, stopFun=BIC, verbose=TRUE)
pboost(y ~ ., DF, lm, residuals, EBIC, verbose=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.